<?php
declare(strict_types=1);

namespace Inti\Media\Container;

use Psr\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\FilesystemAdapter;
use Symfony\Component\Cache\Adapter\RedisAdapter;
use Symfony\Contracts\Cache\CacheInterface;
use function realpath;

/**
 * Class ImageMetadataCacheFactory
 *
 * @package Inti\Media\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class ImageMetadataCacheFactory
{
    public function __invoke(ContainerInterface $container): CacheInterface
    {
        $namespace = 'image_metadata';

        if ($container->has('Redis')) {
            $connection = $container->get('Redis');
            return new RedisAdapter($connection, $namespace, 0);
        }

        $config = $container->get('config');
        $directory = realpath($config['filesystems']['image']['options']['location'] . '/.cache');

        return new FilesystemAdapter($namespace, 0, $directory);
    }
}
