<?php
declare(strict_types=1);

namespace Inti\Media\Exception;

use InvalidArgumentException as BaseInvalidArgumentException;
use function get_class;
use function gettype;
use function is_object;
use function sprintf;

/**
 * Class InvalidArgumentException
 *
 * @package Inti\Media\Exception
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
class InvalidArgumentException extends BaseInvalidArgumentException implements ExceptionInterface
{
    public static function typeForArgument(string $name, string $expected, $received): self
    {
        return new self(sprintf(
            'Invalid type of argument %s. Expected %s; received %s instead.',
            $name, $expected,
            is_object($received) ? get_class($received) : gettype($received)
        ));
    }

    /**
     * @param string $name
     * @param mixed $expected
     * @param scalar $received
     * @return static
     */
    public static function scalarValueForArgument(string $name, $expected, $received): self
    {
        return new self(sprintf(
            'Invalid value of argument %s. Expected %s; received %s instead.',
            $name,
            is_array($expected) ? sprintf('one of: %s', implode(', ', $expected)) : (string) $expected,
            (string) $received
        ));
    }
}
