<?php
declare(strict_types=1);

namespace Inti\Media\Handler;

use Inti\Media\Service\ImageManager;
use Laminas\Diactoros\Response;
use Laminas\Diactoros\Stream;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;

use function ltrim;
use function preg_replace;
use function rawurldecode;

/**
 * Class Serve
 *
 * @package Inti\Media\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class Serve implements RequestHandlerInterface
{
    private ImageManager $images;

    /**
     * Konstruktor.
     *
     * @param ImageManager $images
     */
    public function __construct(ImageManager $images)
    {
        $this->images = $images;
    }

    /**
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $path = ltrim(rawurldecode($request->getUri()->getPath()), '/');
        $path = preg_replace('/\.[a-z0-9]{32}\./', '.', $path);

        if (!$this->images->has($path)) {
            return new Response\EmptyResponse(404);
        }

        $this->images->read($path);
        $fullPath = $this->images->getFullPath($path);

        return new Response(new Stream($fullPath), 200, [
            'Content-Type' => 'image/webp',
        ]);
    }
}
