<?php
declare(strict_types=1);

namespace Inti\Media\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class HttpMethodMiddlewareDecorator
 *
 * @package Inti\Media\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class HttpMethodMiddlewareDecorator implements MiddlewareInterface
{
    private MiddlewareInterface $middleware;
    /** @var array|array[]|string|string[] */
    private $httpMethods;

    /**
     * Konstruktor.
     *
     * @param array|string $httpMethods
     * @param MiddlewareInterface $middleware
     */
    public function __construct($httpMethods, MiddlewareInterface $middleware)
    {
        $this->httpMethods = !is_array($httpMethods) ? [$httpMethods] : $httpMethods;
        $this->middleware = $middleware;
    }

    /**
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (in_array($request->getMethod(), $this->httpMethods)) {
            return $this->middleware->process($request, $handler);
        }

        return $handler->handle($request);
    }
}
